Module utils

Module utils 

Functions for advanced input processing.

Functions in this module should be used by external tools that uses miniquad system, like different UI libraries. User shouldn’t use this function.

Functions

register_input_subscriber
Register input subscriber. Returns subscriber identifier that must be used in repeat_all_miniquad_input.
repeat_all_miniquad_input
Repeats all events that came since last call of this function with current value of subscriber. This function must be called at each frame.