pub struct TextParams<'a> {
pub font: Option<&'a Font>,
pub font_size: u16,
pub font_scale: f32,
pub font_scale_aspect: f32,
pub rotation: f32,
pub color: Color,
}Expand description
Arguments for “draw_text_ex” function such as font, font_size etc
Fields
font: Option<&'a Font>font_size: u16Base size for character height. The size in pixel used during font rasterizing.
font_scale: f32The glyphs sizes actually drawn on the screen will be font_size * font_scale However with font_scale too different from 1.0 letters may be blurry
font_scale_aspect: f32Font X axis would be scaled by font_scale * font_scale_aspect and Y axis would be scaled by font_scale Default is 1.0
rotation: f32Text rotation in radian Default is 0.0
color: ColorTrait Implementations
Sourceimpl<'a> Clone for TextParams<'a>
impl<'a> Clone for TextParams<'a>
Sourcefn clone(&self) -> TextParams<'a>
fn clone(&self) -> TextParams<'a>
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl<'a> Debug for TextParams<'a>
impl<'a> Debug for TextParams<'a>
Sourceimpl<'a> Default for TextParams<'a>
impl<'a> Default for TextParams<'a>
Sourcefn default() -> TextParams<'a>
fn default() -> TextParams<'a>
Returns the “default value” for a type. Read more