pub struct TextDimensions {
pub width: f32,
pub height: f32,
pub offset_y: f32,
}Expand description
World space dimensions of the text, measured by “measure_text” function
Fields
width: f32Distance from very left to very right of the rasterized text
height: f32Distance from the bottom to the top of the text.
offset_y: f32Height offset from the baseline of the text. “draw_text(.., X, Y, ..)” will be rendered in a “Rect::new(X, Y - dimensions.offset_y, dimensions.width, dimensions.height)” For reference check “text_measures” example.